@@ -10,7 +10,7 @@ from string import uppercase
 
 class Excel:
     '''
-    Wrapper for MS Excel derived from that in Python Programing on Win32
+    Wrapper for MS Excel derived from that in Python Programming on Win32
     '''
     def __init__(self,filename=None):
         '''
@@ -125,7 +125,7 @@ class Excel:
         
         Optionally, you specify only the top-left corner of range in
         row1, cell1 and specify row2<=0 - the other coordinate is figured
-        out from the dimension of the data.  This can always be overriden by
+        out from the dimension of the data.  This can always be overridden by
         specifying the full range coordinates.
 
         If no coordinates are given, the data is put into the top left
@@ -146,7 +146,7 @@ class Excel:
 
     def getContiguousRange(self, row1, col1, sheet=1):
         '''
-        Returns data in the range which forms a continguous
+        Returns data in the range which forms a contiguous
         block with top-left corner in cell (row1,col1).
         
         Starting from the specified cell, scan down/across
@@ -208,14 +208,14 @@ class Excel:
 
         charttype = 'xy'   ... XY scatter plot with lines and points.
         .           First series is X.  Others are y1, y2, etc.
-        .         = 'surface' ... Surfce plot of a scalar function of
+        .         = 'surface' ... Surface plot of a scalar function of
         .           two variables.  Data should be a grid of the function.
         .         = 'contour' or 'colorcontour' ... Contour plot of a scalar
         .           function of two variables.  Data should be a grid of
         .           values.
         xmin and xmax = min/max values of the x or category axis
         .         It defaults to autoscale by Excel.  This only applies to
-        .         XY plots (since the surfce/contor plots do not use
+        .         XY plots (since the surface/contor plots do not use
         .         values for the category axes ... they use string labels)
         ymin and ymax = min/max values of the y or value axis
         .         It defaults to auto by Excel.  Applies to all charts.
@@ -239,8 +239,7 @@ class Excel:
         try:
             charttype = charttypes[charttype]
         except KeyError:
-            print 'Excel.chartSelectedRange: Unkown charttype', charttype, \
-                  ' defaulting to XY'
+            print('Excel.chartSelectedRange: Unknown charttype', charttype, ' defaulting to XY')
             charttype = charttypes['xy']
 
         # Make the chart and set how the data will be interpreted
@@ -254,8 +253,7 @@ class Excel:
         elif plotby == 'columns':
             self.xlApp.ActiveChart.PlotBy = xlColumns
         else:
-            print 'Excel.chartSelectedRange: Unknown plotby', charttype, \
-                  ' defaulting to columns'
+            print('Excel.chartSelectedRange: Unknown plotby', charttype, ' defaulting to columns')
             self.xlApp.ActiveChart.PlotBy = xlColumns
 
         # Set the title and axis labels
@@ -309,27 +307,27 @@ class Excel:
 
     def a1(self, row, col, absrow=0, abscol=0):
         '''
-        Return a string that may be used to adress the cell in
-        a formula.  The row and/or column adress may be made absolute
+        Return a string that may be used to address the cell in
+        a formula.  The row and/or column address may be made absolute
         by setting absrow/col to true values.
         
-        Internally we are adressing cells in the spreadsheet using
+        Internally we are addressing cells in the spreadsheet using
         integers (row,col), which is what Excel calls R1C1 style
         references.  But, unless the user has turned-on R1C1 style
-        adressing (unlikely!) this will not work in formulae
-        so we must translate to the usual adressing style, called A1,
+        addressing (unlikely!) this will not work in formulae
+        so we must translate to the usual addressing style, called A1,
         which uses letters for the columns and numbers for the rows,
         writing the column index first.
 
         E.g., A1 = R1C1 = (1,1), and B3 = R3C2 = (3,2).
 
-        Absolute adresses are preceded with a $ symbol.
+        Absolute addresses are preceded with a $ symbol.
         '''
         ar = ac = ''
         if absrow: ar = '$'
         if abscol: ac = '$'
         if col < 1 or col > 256:
-            raise RangeError, 'column index must be in [1,256]'
+            raise RangeError('column index must be in [1,256]')
         (c1,c2) = divmod(col-1,26)
         if c1:
             c = uppercase[c1] + uppercase[c2]
@@ -368,21 +366,21 @@ if __name__ == "__main__":
     import time
     # Make a worksheet and test set/getCell
     xls = Excel()
-    print ' Setting cell(2,2) to "Hi"'
+    print(' Setting cell(2,2) to "Hi"')
     xls.setCell("Hi", 2, 2)
-    print xls.getCell(2,2)
-    print ' Setting cell(1,2) to "(1,2)"'
+    print(xls.getCell(2,2))
+    print(' Setting cell(1,2) to "(1,2)"')
     xls.setCell("(1,2)", 1, 2)
-    print ' Setting cell(2,1) to "(1,2)"'
+    print(' Setting cell(2,1) to "(1,2)"')
     xls.setCell("(2,1)", 2, 1)
     xls.visible()
 
     # Test setting a range to a scalar and getting contiguous range
-    print ' Setting 9,1,12,2 to 0'
+    print(' Setting 9,1,12,2 to 0')
     xls.setRange(0,9,1,12,2)
-    print ' Getting same contiguous range back ... expecting matrix(4,2)=0'
+    print(' Getting same contiguous range back ... expecting matrix(4,2)=0')
     value = xls.getContiguousRange(9,1)
-    print value
+    print(value)
 
     # Test setting/getting a range from/to a matrix
     n = 3
@@ -392,12 +390,12 @@ if __name__ == "__main__":
         x[i] = [0]*m
         for j in range(m):
             x[i][j] = i + j
-    print ' Setting range (3:,4:) to '
-    print x
+    print(' Setting range (3:,4:) to ')
+    print(x)
     xls.setRange(x,3,4)  # Auto determination of the bottom corner
-    print ' Got back from same range ',3,3,3+n-1,4+m-1
+    print(' Got back from same range ',3,3,3+n-1,4+m-1)
     y = xls.getRange(3,4,3+n-1,4+m-1)
-    print y
+    print(y)
 
     # Add names for the series that will eventually become the chart
     names = []
@@ -406,7 +404,7 @@ if __name__ == "__main__":
     xls.setRange(names,2,4)
 
     # Test selecting a range
-    print ' Selecting range ', 3,3,3+n-1,4+m-1
+    print(' Selecting range ', 3,3,3+n-1,4+m-1)
     xls.selectRange(3,4,3+n-1,4+m-1)
 
     # Test general matrix
@@ -420,7 +418,7 @@ if __name__ == "__main__":
     
     # Test making an x-y plot just from the data ... use a
     # second sheet and the simple chart interface
-    print ' Creating chart of sin(x) and cos(x) using second sheet'
+    print(' Creating chart of sin(x) and cos(x) using second sheet')
     n = 20
     m = 3
     h = 2*pi/(n-1)
@@ -435,26 +433,22 @@ if __name__ == "__main__":
     # Use absolute values for the rows but not the columns to test
     # reuse of the formula.
     formula = '=sum('+xls.a1(2,2,absrow=1)+':'+xls.a1(21,2,absrow=1)+')'
-    print ' The formula is ', formula
+    print(' The formula is ', formula)
     xls.setCell('Total',23,1,sheet=2)
     xls.setCell(formula,23,2,sheet=2)
     xls.setCell(formula,23,3,sheet=2)
     # Getting the cell contents back will get the value not the formula
-    print ' The formula from the sheet is ', xls.getCellFormula(23,2,sheet=2)
-    print ' The value of the formula (sum of sin) is ', \
-          xls.getCell(23,2,sheet=2)
-    print ' The formula from where there is only the value "Total" is', \
-          xls.getCellFormula(23,1,sheet=2)
-    print ' The formula from where there is nothing ',\
-          xls.getCellFormula(23,4,sheet=2)
-    print ' The value from where there is nothing ',\
-          xls.getCell(23,4,sheet=2)
+    print(' The formula from the sheet is ', xls.getCellFormula(23,2,sheet=2))
+    print(' The value of the formula (sum of sin) is ', xls.getCell(23,2,sheet=2))
+    print(' The formula from where there is only the value "Total" is', xls.getCellFormula(23,1,sheet=2))
+    print(' The formula from where there is nothing ', xls.getCellFormula(23,4,sheet=2))
+    print(' The value from where there is nothing ', xls.getCell(23,4,sheet=2))
 
     # Make a surface plot by creating a 2-D grid bordered on the
     # left and top with strings to indicate the values.  Note the
     # use of a single quote before the value in the labels in
     # order to force Excel to treat them as strings.
-    print ' Create surface chart of exp(-0.1*r*r)*cos(1.3*r)'
+    print(' Create surface chart of exp(-0.1*r*r)*cos(1.3*r)')
     n = 10
     h = 2*pi/(n-1)
     data = range(n+1)
@@ -487,7 +481,7 @@ if __name__ == "__main__":
         xls.setRange(data,1,5,sheet=2)
 
     # Finally make a chart with all options set
-    print ' Creating chart of sin(x) and cos(x) using second sheet'
+    print(' Creating chart of sin(x) and cos(x) using second sheet')
     n = 81
     data = range(n+1)
     data[0] = ['Age', 'Wisdom']
