@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 #      ifeq ($(shell basename -- $(FC)| cut -d \- -f 1),nvfortran)
 #gcc  or gfortran?
-if [[ "$1" == *fortran* ]] && [[ ! -z $_FC ]]; then
+if [[ "$1" == *fortran* || "$1" == *f90* ]] && [[ ! -z $_FC ]]; then
     echo $_FC
 elif [[ "$1" == *cc* ]] && [[ ! -z $_CC ]]; then
     echo $_CC
