@@ -42,9 +42,9 @@ fi
 check_patch
 rm -f dftd3.f nwpwxc_vdw3a.F
 export PATH=`pwd`:$PATH
-URL1="https://www.chemie.uni-bonn.de/grimme/de/software/dft-d3/dftd3.tgz"
+URL1="https://www.chemie.uni-bonn.de/grimme/de/software/dft-d3/"
 #URL1="https://www.chemiebn.uni-bonn.de/pctc/mulliken-center/software/dft-d3/"
-URL2="https://web.archive.org/web/20210527062154if_/https://www.chemie.uni-bonn.de/pctc/mulliken-center/software/dft-d3/"
+URL2="https://web.archive.org/web/20241209131729/https://www.chemie.uni-bonn.de/grimme/de/software/dft-d3/"
 declare -a urls=("$URL1" "$URL1" "$URL1" "$URL2" "$URL2")
 TGZ=dftd3.tgz
 # check gzip integrity
