@@ -1,6 +1,6 @@
 #ifndef _Becke_EXCHANGE_H_
 #define _Becke_EXCHANGE_H_
 
-extern void   R_Becke_Exchange();
+extern void   R_Becke_Exchange(double *, double *, double *, double *);
 #endif
 /* $Id$ */
