@@ -1,5 +1,5 @@
 /*
- $Id: pauli.h 19707 2010-10-29 17:59:36Z d3y133 $
+ $Id$
 */
 #ifndef _PAULI_H_
 #define _PAULI_H_
@@ -11,7 +11,7 @@
 
 */
 
-extern void   R_Pauli();
-extern void   R_Pauli_Fixed_E();
+extern void   R_Pauli(int, int, double ,double *, int *, double *, double *, double *);
+extern void   R_Pauli_Fixed_E(int, int, double ,double *, int , double , double *, double *);
 
 #endif
