@@ -1,7 +1,3 @@
-/*
- $Id$
-*/
-
 #include <math.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -16,61 +12,25 @@
 #include "paw_scattering.h"
 #include "paw_loggrid.h"
 
-#if defined(CRAY) || defined(CRAY_T3D)
-#include <fortran.h>
-#if !defined(__crayx1)
-#define USE_FCD
-#endif
-#endif
-
-#if (defined(CRAY) || defined(WIN32)) && !defined(__crayx1) &&!defined(__MINGW32__)
+#if (defined(CRAY) || defined(WIN32)) && !defined(__MINGW32__)
 #define teter_parse_ PAW_ATOM_DRIVER
 #endif
 
-void FATR paw_atom_driver_
-#if defined(USE_FCD)
-(Integer *debug_ptr,
- Integer *lmax_ptr,
- Integer *locp_ptr,
- double  *rlocal_ptr,
- const _fcd fcd_sdir_name,
- Integer *n9,
- const _fcd fcd_dir_name,
- Integer *n0,
- const _fcd fcd_in_filename,
- Integer *n1,
- const _fcd fcd_out_filename,
- Integer *n2,
- const _fcd fcd_atom,
- Integer *n3)
+void FATR paw_atom_driver_(Integer *debug_ptr,
+                           Integer *lmax_ptr,
+                           Integer *locp_ptr,
+                           double  *rlocal_ptr,
+                           char    sdir_name[],
+                           Integer *n9,
+                           char    dir_name[],
+                           Integer *n0,
+                           char    in_filename[],
+                           Integer *n1,
+                           char    out_filename[],
+                           Integer *n2,
+                           char    atom[],
+                           Integer *n3)
 {
-    char *sdir_name    = _fcdtocp(fcd_sdir_name);
-    char *dir_name     = _fcdtocp(fcd_dir_name);
-    char *in_filename  = _fcdtocp(fcd_in_filename);
-    char *out_filename = _fcdtocp(fcd_out_filename);
-    char *atom         = _fcdtocp(fcd_atom);
-
-#else
-(debug_ptr,lmax_ptr,locp_ptr,rlocal_ptr,
- sdir_name,n9,dir_name,n0,in_filename,n1,out_filename,n2,atom,n3)
-Integer *debug_ptr;
-Integer *lmax_ptr;
-Integer *locp_ptr;
-double  *rlocal_ptr;
-char    sdir_name[];
-Integer *n9;
-char    dir_name[];
-Integer *n0;
-char    in_filename[];
-Integer *n1;
-char    out_filename[];
-Integer *n2;
-char    atom[];
-Integer *n3;
-{
-
-#endif
-
     int      debug;
     int      lmax_out,locp_out;
     double   rlocal_out;
