@@ -6,11 +6,11 @@
 /* get_cs.h
 */
 
-extern  void	p_xpansion();
-extern  void	dp_xpansion();
-extern  void	ddp_xpansion();
-extern  void	dddp_xpansion();
-extern  void	ddddp_xpansion();
+extern  void	p_xpansion(double *);
+extern  void	dp_xpansion(double *);
+extern  void	ddp_xpansion(double *);
+extern  void	dddp_xpansion(double *);
+extern  void	ddddp_xpansion(double *);
 extern	void	psp_xpansion();
 extern	void	psi_xpansion();
 extern	void	dpsi_xpansion();
