@@ -66,7 +66,7 @@
 #
 #    f(x,y) := (x+y)^2*h(x,y) - x^2*h(x,0) - y^2*h(0,y)
 #
-# so we need to distinguish every invokation based on the arguments passed in.
+# so we need to distinguish every invocation based on the arguments passed in.
 # In addition, in our case, h is actually implemented as a subroutine that
 # returns the function value and the values of the various derivatives. The
 # inputs and outputs are stored in arrays. The steps required are:
@@ -98,7 +98,7 @@ func_lda      = 1
 func_gga      = 2
 func_mgga     = 3
 
-version = "$Id: call_subroutine.py 27339 2015-08-13 18:39:43Z d3y133 $"
+version = "$Id$"
 version = version.split()
 revision = version[1]+" revision "+version[2]+" "+version[3]
 
@@ -116,7 +116,7 @@ def usage(code):
    sys.stderr.write("<fileout>     Fortran from Maxima with subroutine calls")
    sys.stderr.write("              for functionals")
    sys.stderr.write("")
-   sys.stderr.write("$Id: call_subroutine.py 27339 2015-08-13 18:39:43Z d3y133 $")
+   sys.stderr.write("$Id$")
    sys.exit(code)
 
 def var_to_int(var):
@@ -136,6 +136,7 @@ def unwrap_lines(lines_in):
    pattern = re.compile("     [0-9:;<=>?@+]")
    lines_out = []
    longline = ""
+   length = 0
    for line in lines_in:
       length = len(line)
       if pattern.match(line):
@@ -705,6 +706,7 @@ def find_varname(dict,diffstr):
    functional value rather than a derivative and we return e.g. s3f.
    The indicated variable is returned as a string.
    """
+   length = 0
    data = diffstr
    #DEBUG
    #print "find_varname: data:",data
