@@ -115,32 +115,6 @@
 #define DLAMCHU        2.2250738585072014e-308
 */
 
-#endif
-#ifdef __crayx1
-#define DLAMCHE 2.2204460492503130e-16
-#define DLAMCHP 2.2204460492503130e-16
-#define DLAMCHB 2.0000000000000000e+00
-#define DLAMCHS 2.2250738585072014e-308
-#define DLAMCHU 2.2250738585072014e-308
-
-#define yscal_  sscal_
-#define ydot_   sdot_
-#define yaxpy_  saxpy_
-#define ynrm2_  snrm2_
-#define yasum_  sasum_
-#define ycopy_  scopy_
-#define iyamax_ isamax_
-
-/*
-  lapack
-  */
-
-#define ylagtf_ slagtf_
-#define ylagts_ slagts_
-#define dlamch_ slamch_
-#define ylarnv_ slarnv_
-
-
 #endif
 #ifdef PENTIUM
 /* wild ass guess; same as sparc */
