@@ -51,11 +51,11 @@
       orthogonalization criterion for each block was based on norm(Ti).
 
       This assumption about accuracy is consistent with taking 
-      abstol <= 0.0 in ystebz, pdspev, etc., i.e., then ystebz/pstebz
+      abstol <= 0.0 in dstebz, pdspev, etc., i.e., then dstebz/pstebz
       computes eigenvalues with an error less than eps * norm(T).
 
       In principle the user could specify 0.0 < abstol < eps * norm(T) 
-      in ystebz/pstebz
+      in dstebz/pstebz
       in which case the assumption of this routines may be violated.
       Violation of this assumption will not reduce the accuracy of the
       results, it will only cause the code to run slower since it
@@ -137,11 +137,11 @@ Integer clustrf_ (n, d, e, m, w, mapZ, vecZ, iblock, nsplit, isplit, ptbeval, nu
        d = array of n DoublePrecision; diagonal of the tridiagonal matrices
        e = array of n DoublePrecision; e[0] is junk -- left over from eispack--should remove
        super-diagonal of the tridiagonal matrices; 
-       m = number of the number eigenvalues; from ystebz
-       w = array of m DoublePrecision precision; eigenvalues from ystebz
-       iblock = array of n integers ( at most ); from ystebz
-       nsplit = number of blocks; output of ystebz
-       isplit = split points of blocks; output of ystebz
+       m = number of the number eigenvalues; from dstebz
+       w = array of m DoublePrecision precision; eigenvalues from dstebz
+       iblock = array of n integers ( at most ); from dstebz
+       nsplit = number of blocks; output of dstebz
+       isplit = split points of blocks; output of dstebz
        ptb_eval = perturbed eigenvalues
        
        output:
@@ -190,8 +190,7 @@ Integer clustrf_ (n, d, e, m, w, mapZ, vecZ, iblock, nsplit, isplit, ptbeval, nu
   Integer clustr_check();
   extern Integer count_list();
   extern Integer reduce_list2();
-  extern Integer menode_ ();  
-  extern Integer iyamax_(), mxmynd_ (), mypid();
+  extern Integer mxmynd_ (), mypid();
   extern void fil_int_lst();
   extern void fil_dbl_lst();
   
@@ -204,15 +203,15 @@ Integer clustrf_ (n, d, e, m, w, mapZ, vecZ, iblock, nsplit, isplit, ptbeval, nu
     blas calls
     */
   
-  extern void ycopy_(), yscal_(), yaxpy_();
-  extern DoublePrecision ydot_(), yasum_(), ynrm2_();
+  extern void dcopy_(), dscal_(), daxpy_();
+  extern DoublePrecision ddot_(), dasum_(), dnrm2_();
   
   /*
     lapack calls
     */
   
   extern DoublePrecision dlamch_();
-  extern void xerbla_(), ylagts_(), ylagtf_(), ylarnv_();
+  extern void xerbla_(), dlagts_(), dlagtf_(), dlarnv_();
   
   me = mxmynd_ ();
   num_eig = *m;
@@ -442,8 +441,8 @@ Integer clustrf_ (n, d, e, m, w, mapZ, vecZ, iblock, nsplit, isplit, ptbeval, nu
 	    /*
 	     *info = -5;
 	     i__3 = -(*info);
-	     xerbla_("YSTEIN", &i__3);
-	     xerbla_("YSTEIN", &i__3);
+	     xerbla_("DSTEIN", &i__3);
+	     xerbla_("DSTEIN", &i__3);
 	     */
 	    fprintf(stderr, " Error in ordering eigenvalues: -5 error clustrf me = %d \n", me );
 	    return(-5);
