@@ -105,11 +105,11 @@ Integer clustrfix_ (n, d, e, m, w, iblock, nsplit, isplit, num_clustr, clustr_in
        d = array of n DoublePrecision; diagonal of the tridiagonal matrices
        e = array of n DoublePrecision; e[0] is junk -- left over from eispack--should remove
        super-diagonal of the tridiagonal matrices; 
-       m = number of the number eigenvalues; from ystebz
-       w = array of m DoublePrecision precision; eigenvalues from ystebz
-       iblock = array of n integers ( at most ); from ystebz
-       nsplit = number of blocks; output of ystebz
-       isplit = split points of blocks; output of ystebz
+       m = number of the number eigenvalues; from dstebz
+       w = array of m DoublePrecision precision; eigenvalues from dstebz
+       iblock = array of n integers ( at most ); from dstebz
+       nsplit = number of blocks; output of dstebz
+       isplit = split points of blocks; output of dstebz
        ptb_eval = perturbed eigenvalues
        
        output:
@@ -137,34 +137,9 @@ Integer clustrfix_ (n, d, e, m, w, iblock, nsplit, isplit, num_clustr, clustr_in
   Integer clustr_size=-1, iii, jjj;
   
   DoublePrecision eps, xj1, xj2;
-  DoublePrecision xj, relgap(), delta1, delta2;
-  
-  Integer clustr_check();
-  extern Integer count_list();
-  extern Integer reduce_list2();
-  extern Integer menode_ ();  
-  extern Integer iyamax_(), mxmynd_ (), mypid();
-  extern void fil_int_lst();
-  extern void fil_dbl_lst();
-  
-  /*
-    intrinsic DoublePrecision precision
-    */
-  
-  
-  /*
-    blas calls
-    */
-  
-  extern void ycopy_(), yscal_(), yaxpy_();
-  extern DoublePrecision ydot_(), yasum_(), ynrm2_();
-  
-  /*
-    lapack calls
-    */
-  
-  extern DoublePrecision dlamch_();
-  extern void xerbla_(), ylagts_(), ylagtf_(), ylarnv_();
+  DoublePrecision xj, relgap(DoublePrecision, DoublePrecision), delta1, delta2;
+
+  extern Integer mxmynd_ (), mypid();
   
   me = mxmynd_ ();
   num_eig = m;
@@ -362,7 +337,7 @@ Integer clustrfix_ (n, d, e, m, w, iblock, nsplit, isplit, num_clustr, clustr_in
   
   jjj =0;
   for ( iii = 0; iii < num_cls; iii++ ) {
-    printf(" cptr c1 %d cn  %d b1 %d bn %d \n", clustr_info[jjj], clustr_info[jjj+1], clustr_info[jjj+2], clustr_info[jjj+3]);
+    printf(" cptr c1 %d cn  %d b1 %d bn %d \n", (int)clustr_info[jjj], (int)clustr_info[jjj+1], (int)clustr_info[jjj+2], (int)clustr_info[jjj+3]);
     jjj += 4;
   }
   
