@@ -131,12 +131,12 @@ Integer clustrinv_(n, d, e, eval, schedule, num_clustr, mapZ, mapvecZ, vecZ, imi
 
   
   extern void xerbla_();
-  extern Integer iyamax_(), mclock_(), succ_(), mxmynd_(), mxnprc_();
-  extern DoublePrecision yasum_(), dlamch_(), ynrm2_(), ydot_(), dlarnd_();
-  extern void ylagtf_(), ylarnv_();
+  extern Integer idamax_(), mclock_(), succ_(), mxmynd_(), mxnprc_();
+  extern DoublePrecision dasum_(), dlamch_(), dnrm2_(), ddot_(), dlarnd_();
+  extern void dlagtf_(), dlarnv_();
   extern void printff_(), mgs_3();
-  extern void mgspnl_(), yscal_(), ylagts_();
-  extern void ycopy_(), yaxpy_();
+  extern void mgspnl_(), dscal_(), dlagts_();
+  extern void dcopy_(), daxpy_();
   extern Integer count_list ();
   extern Integer inv_it();
   extern void mgs ();
@@ -438,11 +438,11 @@ Integer clustrinv_(n, d, e, eval, schedule, num_clustr, mapZ, mapvecZ, vecZ, imi
 	  */
 	
         fil_dbl_lst (*n, vecZ[i], 0.0e0);
-	ylarnv_(&three, &iseed[0], &blksiz, &vecZ[i][bb1]);
+	dlarnv_(&three, &iseed[0], &blksiz, &vecZ[i][bb1]);
 	indx++;
       }
       else {
-	ylarnv_(&three, &iseed[0], &blksiz, dscrat);
+	dlarnv_(&three, &iseed[0], &blksiz, dscrat);
       }
     }
     
@@ -513,7 +513,7 @@ Integer clustrinv_(n, d, e, eval, schedule, num_clustr, mapZ, mapvecZ, vecZ, imi
       nvecs = 0;
       for (j = c1; j <= cn; j++ ){
         if ( mapZ[j] == me ) {
-	  ycopy_(&blksiz, &vecZ[nvecs+Zvec][bb1], &IONE,
+	  dcopy_(&blksiz, &vecZ[nvecs+Zvec][bb1], &IONE,
                  dscrat+nvecs*blksiz, &IONE );
           nvecs++;
         }
