@@ -88,9 +88,6 @@ Integer inv_it3( n, c1, cn, b1, bn, Zbegin, map, mapvec, vector, d, e, eval, eps
   Integer csiz, ibad;
   Integer indx22;
   
-  extern void yscal_(), ylagtf_(), ylagts_(), ycopy_(), yscal_();
-  extern Integer iyamax_();
-  extern DoublePrecision ynrm2_(), yasum_(), ydot_();
   extern Integer mxmynd_();
   
   extern void mgs_prev ();
@@ -135,14 +132,14 @@ Integer inv_it3( n, c1, cn, b1, bn, Zbegin, map, mapvec, vector, d, e, eval, eps
 #endif      
       
       ptr = &work[indrv1];
-      ycopy_(&blksz, &vector[k][*b1], &IONE, ptr, &IONE );
-      ycopy_(&blksz, &d[*b1], &IONE, &work[indrv4], &IONE);
+      dcopy_(&blksz, &vector[k][*b1], &IONE, ptr, &IONE );
+      dcopy_(&blksz, &d[*b1], &IONE, &work[indrv4], &IONE);
       i_1 = blksz - 1;
-      ycopy_(&i_1, &e[*b1+1], &IONE, &work[ indrv2 + 1 ], &IONE);
-      ycopy_(&i_1, &e[*b1+1], &IONE, &work[ indrv3 ], &IONE);
+      dcopy_(&i_1, &e[*b1+1], &IONE, &work[ indrv2 + 1 ], &IONE);
+      dcopy_(&i_1, &e[*b1+1], &IONE, &work[ indrv3 ], &IONE);
       
       tol = ZERO;
-      ylagtf_( &blksz, &work[indrv4], &xj, &work[indrv2 + 1], &work[indrv3], &tol,
+      dlagtf_( &blksz, &work[indrv4], &xj, &work[indrv2 + 1], &work[indrv3], &tol,
 	       &work[indrv5], &iwork[0], &info);
       
       /*
@@ -187,7 +184,7 @@ Integer inv_it3( n, c1, cn, b1, bn, Zbegin, map, mapvec, vector, d, e, eval, eps
 	Normalize and scale the righthand side vector Pb.
       */
       
-      scl = yasum_(&blksz, ptr, &IONE);
+      scl = dasum_(&blksz, ptr, &IONE);
       scl = ((DoublePrecision) 1.0e0)/scl;
       scl *= (DoublePrecision) blksz ;
       scl *= *onenrm ;
@@ -196,7 +193,7 @@ Integer inv_it3( n, c1, cn, b1, bn, Zbegin, map, mapvec, vector, d, e, eval, eps
       */
 
       scl *= max(*eps, FABS(work[indrv4 + blksz - 1]) / *onenrm );
-      yscal_(&blksz, &scl, ptr, &IONE );
+      dscal_(&blksz, &scl, ptr, &IONE );
       
       /*
 	Solve the system LU = Pb.
@@ -205,10 +202,10 @@ Integer inv_it3( n, c1, cn, b1, bn, Zbegin, map, mapvec, vector, d, e, eval, eps
       tol = ZERO;
       
       
-      ylagts_( &IMINUSONE, &blksz, &work[indrv4], &work[ indrv2 + 1],
+      dlagts_( &IMINUSONE, &blksz, &work[indrv4], &work[ indrv2 + 1],
 	       &work[indrv3], &work[indrv5], &iwork[0], ptr, &tol, &info);
       
-      jmax = iyamax_(&blksz, ptr, &IONE);
+      jmax = idamax_(&blksz, ptr, &IONE);
       nrm = FABS(ptr[jmax - 1]);
       
       if ( nrm < *stpcrt ) goto loop;
@@ -222,10 +219,10 @@ Integer inv_it3( n, c1, cn, b1, bn, Zbegin, map, mapvec, vector, d, e, eval, eps
 	exit(1);
 	*/
       
-      scl = ynrm2_(&blksz, ptr, &IONE);
+      scl = dnrm2_(&blksz, ptr, &IONE);
       scl = ((DoublePrecision) 1.0e0)/scl;
-      yscal_(&blksz, &scl, ptr, &IONE);
-      ycopy_( &blksz, ptr, &IONE, vector[k] + *b1, &IONE);
+      dscal_(&blksz, &scl, ptr, &IONE);
+      dcopy_( &blksz, ptr, &IONE, vector[k] + *b1, &IONE);
       k++;
     }
   }
