@@ -77,12 +77,7 @@ Integer inv_it5( n, c1, cn, b1, bn, Zbegin, map, mapvec, vector, d, e, ld, lld,
   DoublePrecision ztz=0.;
   Integer zbegin1, kk, zend, bb1 = *b1+1, bbn = *bn+1, *iwork1;
   
-  extern void yscal_(), ylagtf_(), ylagts_(), ycopy_(), yscal_();
-  extern Integer iyamax_();
-  extern DoublePrecision ynrm2_(), yasum_(), ydot_();
   extern Integer mxmynd_();
-  extern DoublePrecision dgetavec_();
-  
   
   extern void mgs_prev ();
   
@@ -131,7 +126,7 @@ Integer inv_it5( n, c1, cn, b1, bn, Zbegin, map, mapvec, vector, d, e, ld, lld,
 #endif
       
       ztz = 1.e0/ztz;
-      yscal_(&blksz, &ztz, &vector[k][*b1], &IONE);
+      dscal_(&blksz, &ztz, &vector[k][*b1], &IONE);
       i_1++;
       k++;
     }
