@@ -97,30 +97,9 @@ void lu_mxm2( n, Lmatrix, mapL, m, colU, mapU, iscratch, scratch)
 
   DoublePrecision *buffer, *dptr, *in_buffer, *out_buffer;
   DoublePrecision *Uvec, *Lvec, t;
-  
-  /*
-    blas calls
-    */
 
-  extern void ycopy_(), yaxpy_();
-  extern DoublePrecision ydot_();
   extern Integer mxmynd_();
-  extern void xerbla_();
-  extern void mapdif1_();
-  extern void gshellsort_();
-  extern Integer indxL();
 
-  /* 
-    mxsubs calls
-    */
-
-  extern Integer mxwrit_(),  mxread_();
-  extern Integer count_list();
-  extern Integer fil_mapvec_();
-  extern Integer ci_size_();
-  extern void zero_out();
-  extern Integer reduce_list2();
-  
   i = 0;
   me = mxmynd_();
 
@@ -294,10 +273,10 @@ void lu_mxm2( n, Lmatrix, mapL, m, colU, mapU, iscratch, scratch)
   indx = 0;
   for ( jndx = 0; jndx < nvecsU; jndx++ ){
     isize = ll - mapvecU[jndx];
-    ycopy_( &isize, colU[jndx], &IONE, &buffer[indx], &IONE);
+    dcopy_( &isize, colU[jndx], &IONE, &buffer[indx], &IONE);
     indx += isize;
     isize = ll - mapvecL[jndx];
-    ycopy_( &isize, Lmatrix[jndx], &IONE, &buffer[indx], &IONE);
+    dcopy_( &isize, Lmatrix[jndx], &IONE, &buffer[indx], &IONE);
     indx += isize;
   }
   buffer += indx;
@@ -337,7 +316,7 @@ void lu_mxm2( n, Lmatrix, mapL, m, colU, mapU, iscratch, scratch)
 	isize = ll - k;
 	iii = k - j;
 	t = Uvec[iii];
-	yaxpy_( &isize, &t, Lvec+iii, &IONE, Lmatrix[indx], &IONE);
+	daxpy_( &isize, &t, Lvec+iii, &IONE, Lmatrix[indx], &IONE);
       }
     }
     dptr += 2*(ll-j);
@@ -356,11 +335,11 @@ void lu_mxm2( n, Lmatrix, mapL, m, colU, mapU, iscratch, scratch)
   me_indx += nproc;
   
   for ( i = 0; i < nproc-1 ; i++ ) {
-    ycopy_(&osize, in_buffer, &IONE, out_buffer, &IONE);
+    dcopy_(&osize, in_buffer, &IONE, out_buffer, &IONE);
     if ( (me_indx % 2) ==  0 ) {
       rsize = osize * sizeof(DoublePrecision);
       if ( rsize != 0 ) {
-	rsize = mxwrit_( out_buffer, &rsize, &next_proc, &i );
+	rsize = mxwrit_( (DoublePrecision *)out_buffer, &rsize, &next_proc, &i );
       }
       
       indx = ( me_indx-i-1 ) % nproc;
@@ -374,7 +353,7 @@ void lu_mxm2( n, Lmatrix, mapL, m, colU, mapU, iscratch, scratch)
       
       rsize = isize*sizeof(DoublePrecision);
       if ( rsize != 0 ){
-	rsize = mxread_( in_buffer, &rsize, &last_proc, &i );
+	rsize = mxread_( (DoublePrecision *) in_buffer, &rsize, &last_proc, &i );
       }
     }
     else {
@@ -389,11 +368,11 @@ void lu_mxm2( n, Lmatrix, mapL, m, colU, mapU, iscratch, scratch)
       
       rsize = isize * sizeof(DoublePrecision);
       if ( rsize != 0 )
-	rsize = mxread_( in_buffer, &rsize, &last_proc, &i );
+	rsize = mxread_( (DoublePrecision *)in_buffer, &rsize, &last_proc, &i );
       
       rsize = osize * sizeof(DoublePrecision);
       if ( rsize != 0 ){
-	rsize = mxwrit_( out_buffer, &rsize, &next_proc, &i );
+	rsize = mxwrit_((DoublePrecision *)out_buffer, &rsize, &next_proc, &i );
       }
     }
     
@@ -410,7 +389,7 @@ void lu_mxm2( n, Lmatrix, mapL, m, colU, mapU, iscratch, scratch)
 	  i_dummy = ll - k;
 	  iii = k - j;
 	  t = Uvec[iii];
-	  yaxpy_( &i_dummy, &t, Lvec+iii, &IONE, Lmatrix[indx], &IONE);
+	  daxpy_( &i_dummy, &t, Lvec+iii, &IONE, Lmatrix[indx], &IONE);
 	}
       }
       dptr += 2*(ll-j);
