@@ -86,9 +86,9 @@ void mgs_3( n, colF, mapF, b1, bn, nvecsZ, first, first_buf, iscratch, scratch)
     blas calls
     */
 
-  extern void ycopy_(), yaxpy_(), yscal_();
-  extern DoublePrecision ydot_();
-  extern DoublePrecision ynrm2_();
+  extern void dcopy_(), daxpy_(), dscal_();
+  extern DoublePrecision ddot_();
+  extern DoublePrecision dnrm2_();
   extern void bbcast00();
 
   /* 
@@ -160,13 +160,13 @@ void mgs_3( n, colF, mapF, b1, bn, nvecsZ, first, first_buf, iscratch, scratch)
     k = *nvecsZ;
     for ( jndx = k; jndx < k + nvecs; jndx++ ){
 	dptr = &colF[jndx][bb];
-	t = ynrm2_( &vec_len, dptr, &IONE );
+	t = dnrm2_( &vec_len, dptr, &IONE );
 	t = (DoublePrecision) 1.0e0/t;
-	yscal_( &vec_len, &t, dptr, &IONE);
+	dscal_( &vec_len, &t, dptr, &IONE);
 	for ( indx = jndx + 1; indx < k + nvecs; indx++ ){
 	  dptr1 = &colF[indx][bb];
-	  t = -ydot_( &vec_len, dptr, &IONE, dptr1, &IONE );
-	  yaxpy_( &vec_len, &t, dptr, &IONE, dptr1, &IONE );
+	  t = -ddot_( &vec_len, dptr, &IONE, dptr1, &IONE );
+	  daxpy_( &vec_len, &t, dptr, &IONE, dptr1, &IONE );
 	}
     }
     return;
@@ -191,7 +191,7 @@ void mgs_3( n, colF, mapF, b1, bn, nvecsZ, first, first_buf, iscratch, scratch)
 
   if( me == proclist[1] ) {
     isize = vec_len * nvecs_in;
-    ycopy_( &isize, first_buf, &IONE, in_buffer, &IONE);
+    dcopy_( &isize, first_buf, &IONE, in_buffer, &IONE);
   }
 
   if( nproc > 2 ) {
@@ -207,8 +207,8 @@ void mgs_3( n, colF, mapF, b1, bn, nvecsZ, first, first_buf, iscratch, scratch)
     dptr = &colF[iii][bb];
     dptr1 = in_buffer;
     for ( jndx = 0; jndx < nvecs_in; jndx++ ){
-      t = -ydot_( &vec_len, dptr, &IONE, dptr1, &IONE);
-      yaxpy_( &vec_len, &t, dptr1, &IONE, dptr, &IONE );
+      t = -ddot_( &vec_len, dptr, &IONE, dptr1, &IONE);
+      daxpy_( &vec_len, &t, dptr1, &IONE, dptr, &IONE );
       dptr1 += vec_len;
     }
   }
@@ -248,14 +248,14 @@ void mgs_3( n, colF, mapF, b1, bn, nvecsZ, first, first_buf, iscratch, scratch)
       
         for ( jndx = kk; jndx < kk + mvecs; jndx++ ){
  	  dptr = &colF[jndx][bb];
- 	  t = ynrm2_( &vec_len, dptr, &IONE );
+ 	  t = dnrm2_( &vec_len, dptr, &IONE );
 	  t = 1.0e0/t;
-	  yscal_( &vec_len, &t, dptr, &IONE);
+	  dscal_( &vec_len, &t, dptr, &IONE);
 	  for ( indx = jndx + 1; indx < kk + mvecs; indx++ ){
 	    dptr1 = &colF[indx][bb];
-	    t = ydot_( &vec_len, dptr, &IONE, dptr1, &IONE );
+	    t = ddot_( &vec_len, dptr, &IONE, dptr1, &IONE );
 	    t *= MONE;
-	    yaxpy_( &vec_len, &t, dptr, &IONE, dptr1, &IONE );
+	    daxpy_( &vec_len, &t, dptr, &IONE, dptr1, &IONE );
 	  }
         }
 
@@ -263,7 +263,7 @@ void mgs_3( n, colF, mapF, b1, bn, nvecsZ, first, first_buf, iscratch, scratch)
       
    	dptr = in_buffer;
 	for ( indx = kk; indx < kk + mvecs; indx++ ){
-	  ycopy_( &vec_len, &colF[indx][bb], &IONE, dptr, &IONE);
+	  dcopy_( &vec_len, &colF[indx][bb], &IONE, dptr, &IONE);
 	  dptr += vec_len;
         }
 
@@ -283,9 +283,9 @@ void mgs_3( n, colF, mapF, b1, bn, nvecsZ, first, first_buf, iscratch, scratch)
           dptr = &colF[iii][bb];
           dptr1 = in_buffer;
           for ( jndx = 0; jndx < mvecs; jndx++ ){
-            t = ydot_( &vec_len, dptr, &IONE, dptr1, &IONE);
+            t = ddot_( &vec_len, dptr, &IONE, dptr1, &IONE);
 	    t *= MONE;
-            yaxpy_( &vec_len, &t, dptr1, &IONE, dptr, &IONE );
+            daxpy_( &vec_len, &t, dptr1, &IONE, dptr, &IONE );
             dptr1 += vec_len;
           }
         }
@@ -301,14 +301,14 @@ void mgs_3( n, colF, mapF, b1, bn, nvecsZ, first, first_buf, iscratch, scratch)
 
     for ( jndx = k; jndx < k + nvecs; jndx++ ){
       dptr = &colF[jndx][bb];
-      t = ynrm2_( &vec_len, dptr, &IONE );
+      t = dnrm2_( &vec_len, dptr, &IONE );
       t = 1.0e0/t;
-      yscal_( &vec_len, &t, dptr, &IONE);
+      dscal_( &vec_len, &t, dptr, &IONE);
       for ( indx = jndx + 1; indx < k + nvecs; indx++ ){
         dptr1 = &colF[indx][bb];
-        t = ydot_( &vec_len, dptr, &IONE, dptr1, &IONE );
+        t = ddot_( &vec_len, dptr, &IONE, dptr1, &IONE );
 	t *= MONE;
-        yaxpy_( &vec_len, &t, dptr, &IONE, dptr1, &IONE );
+        daxpy_( &vec_len, &t, dptr, &IONE, dptr1, &IONE );
       }
     }
   }
