@@ -128,38 +128,8 @@ void mxm5x( n, rowU, mapU, m, colF, mapF, iscratch, scratch)
   DoublePrecision *buffer, *d_ptr, *in_buffer, *out_buffer;
   DoublePrecision *F_ptr, *U_ptr, t;
 
-  
-  
-  /*
-    blas calls
-    */
-  
-  extern void ycopy_(), yaxpy_();
-  extern DoublePrecision ydot_();
-
   extern Integer mxmynd_();
-  extern void xerbla_();
-  extern void mapdif1_();
-  extern void g_exit_();
-  extern void pxerbla2_();
-  extern Integer fil_mapvec_();
-  extern void chol_pipe_bcast();
-  extern void gshellsort_();
-  extern Integer indxL();
-  extern void fil_dbl_lst();
-
-  
-  /* 
-    mxsubs calls
-    */
-  
-  extern Integer mxwrit_(),  mxread_();
-  extern Integer count_list();
-  extern Integer fil_mapvec_();
-  extern Integer ci_size_();
-  extern Integer reduce_list2();
-  extern Integer peigs_cmod_();
-  
+ 
   i = 0;
   me = mxmynd_();
 
@@ -344,7 +314,7 @@ void mxm5x( n, rowU, mapU, m, colF, mapF, iscratch, scratch)
   buffer = (DoublePrecision *) scratch;
   indx = 0;
   for ( jndx = 0; jndx < nvecsF; jndx++ ){
-    ycopy_( &ll, colF[jndx], &ONE, &buffer[indx], &ONE);
+    dcopy_( &ll, colF[jndx], &ONE, &buffer[indx], &ONE);
     indx += ll;
   }
   buffer += indx;
@@ -365,7 +335,7 @@ void mxm5x( n, rowU, mapU, m, colF, mapF, iscratch, scratch)
   for ( jndx = 0; jndx < nvecsU; jndx++ ){
     ii = mapvecU[jndx];
     ii = ll - ii;
-    ycopy_( &ii, rowU[jndx], &ONE, d_ptr, &ONE);
+    dcopy_( &ii, rowU[jndx], &ONE, d_ptr, &ONE);
     d_ptr += ii;
   }
   
@@ -379,7 +349,7 @@ void mxm5x( n, rowU, mapU, m, colF, mapF, iscratch, scratch)
     for ( jndx = 0; jndx < nvecsU; jndx++ ) {
       i = mapvecU[jndx];
       isize = ll - i;
-      t = ydot_( &isize, &F_ptr[i], &ONE, U_ptr , &ONE);
+      t = ddot_( &isize, &F_ptr[i], &ONE, U_ptr , &ONE);
       colF[k][i] = t;
       U_ptr += isize;
     }
@@ -394,7 +364,7 @@ void mxm5x( n, rowU, mapU, m, colF, mapF, iscratch, scratch)
   me_indx += nproc;
   
   for ( i = 0; i < nproc-1 ; i++ ) {
-    ycopy_(&osize, in_buffer, &ONE, out_buffer, &ONE);
+    dcopy_(&osize, in_buffer, &ONE, out_buffer, &ONE);
     idummy = 2;
     if ( (me_indx + nproc) % idummy ==  0 ) {
       rsize = osize * sizeof(DoublePrecision);
@@ -452,7 +422,7 @@ void mxm5x( n, rowU, mapU, m, colF, mapF, iscratch, scratch)
       for ( jndx = 0; jndx < nvecsU; jndx++ ) {
 	ii = mapvec_in[jndx];
 	isize = ll - ii;
-	t = ydot_( &isize, &F_ptr[ii], &ONE, U_ptr , &ONE);
+	t = ddot_( &isize, &F_ptr[ii], &ONE, U_ptr , &ONE);
 	colF[k][ii] = t;
 	U_ptr += isize;
       }
