@@ -59,7 +59,7 @@ void pdspeval ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
   
 /*
  *
- *  Our parallel version of LAPACK's yspevx.
+ *  Our parallel version of LAPACK's dspevx.
  *
  *
  *  Purpose
@@ -302,7 +302,7 @@ void pdspeval ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
     extern void     mem_cpy();
     extern void     dshellsort_(), sorteig();
 
-    extern DoublePrecision ynrm2_();
+    extern DoublePrecision dnrm2_();
 
     extern Integer  tred2();
     extern void     pstebz_(), pstein32(), mxm25(), sfnorm();
@@ -655,9 +655,9 @@ void pdspeval ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
 
       if( mapA[0] ==me ) {
         isize = msize - 1;
-        vec[0] = sqrt((DoublePrecision) 2.e0 ) * ynrm2_( &isize, &ee[1], &IONE );
-        vec[1] = ynrm2_( &msize, dd, &IONE );
-        fnormT = ynrm2_( &ITWO, vec, &IONE );
+        vec[0] = sqrt((DoublePrecision) 2.e0 ) * dnrm2_( &isize, &ee[1], &IONE );
+        vec[1] = dnrm2_( &msize, dd, &IONE );
+        fnormT = dnrm2_( &ITWO, vec, &IONE );
 	
         ulp = DLAMCHE * DLAMCHB ;
 
