@@ -65,7 +65,7 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
   
 /*
  *
- *  Our parallel version of LAPACK's yspevx.
+ *  Our parallel version of LAPACK's dspevx.
  *
  *
  *  Purpose
@@ -287,7 +287,6 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
     DoublePrecision **buff_ptr, **vecQ, syncco[1], *perturbeval;
     DoublePrecision smlnum, bignum, eps, rmin, rmax, anrm;
     Integer iscale;
-    extern void yscal_();
 
 #ifdef TIMING
     extern DoublePrecision mxclock_();
@@ -303,18 +302,8 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
  */
     extern Integer  mxmynd_(), mxnprc_();
 
-    extern Integer  mapchk_(), count_list();
-    extern void     memreq_();
-    extern void     pdiff(), xstop_(), pgexit(), mapdif_();
-    extern void     mdiff1_(), mdiff2_(), bbcast00();
-    extern void     mem_cpy();
-    extern void     dshellsort_(), sorteig();
-
-    extern DoublePrecision ynrm2_();
-
-    extern Integer  tred2();
-    extern void     pstebz10_(), pstebz11_(), mxm25(), sfnorm(), pstein4(), pstein5(), pscale_();
-    extern void mxsync_(), gmax00();
+    extern void     pstebz11_(), sfnorm(), pscale_();
+    extern void mxsync_();
     extern void r_ritz_(), tresidd();
     
 /*
@@ -350,7 +339,7 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
     me    = mxmynd_();
     nproc = mxnprc_();
     strcpy( msg,  "Error in pdspevx." );
-    sprintf( filename, "pdspevx.%d", me);
+    sprintf( filename, "pdspevx.%d", (int)me);
     
     /*
       setdbg_(&peigs_DEBUG);
@@ -411,7 +400,7 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
         *info = linfo;
       
       fprintf( stderr, " %s me = %d argument %d is a pointer to NULL. \n",
-	       msg, me, -linfo );
+	       msg, (int)me, (int)(-linfo) );
       xstop_( &linfo );
       return;
     }
@@ -453,7 +442,7 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
    if ( *info != 0 ) {
        linfo = *info;
        fprintf( stderr, " %s me = %d argument %d has an illegal value. \n",
-                msg, me, -linfo);
+                msg, (int)me, (int)(-linfo));
        xstop_( info );
        return;
    }
@@ -480,7 +469,7 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
    if ( *info != 0 ) {
        linfo = *info;
        fprintf( stderr, " %s me = %d argument %d contains a pointer to NULL. \n",
-                msg, me, -linfo);
+                msg, (int)me, (int)(-linfo));
        xstop_( info );
        return;
    }
@@ -495,7 +484,7 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
      *info = -13;
     
    if ( *info != 0 ) {
-       fprintf( stderr, " %s me = %d mapA,Z differ \n", msg, me );
+       fprintf( stderr, " %s me = %d mapA,Z differ \n", msg, (int)me );
        xstop_( info );
        return;
    }
@@ -520,7 +509,7 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
    
    if ( linfo != 0 ) {
      *info = linfo;
-     fprintf( stderr, " %s me = %d Insufficient workspace provided. \n", msg, me );
+     fprintf( stderr, " %s me = %d Insufficient workspace provided. \n", msg, (int)me );
      xstop_( info );
      return;
    }
@@ -761,7 +750,7 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
      for ( iii = 0; iii < msize; iii++){
        if ( mapA[iii] == me ) {
 	 isize = msize - iii;
-	 yscal_(&isize, &sigma, vecA[k], IONE );
+	 dscal_(&isize, &sigma, vecA[k], IONE );
 	 k++;
        }
      }
@@ -791,7 +780,7 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
    */
 
 #ifdef DEBUG7
-   printf(" in pdspevx out tred2 me = %d \n", mxmynd_());
+   printf(" in pdspevx out tred2 me = %d \n", (int)mxmynd_());
    fflush(stdout);
 #endif
    
@@ -819,7 +808,7 @@ void pdspevx ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
       t1 = mxclock_();
 #endif
 #ifdef DEBUG7
-      printf(" in pdspevx pstebz11 me = %d \n", mxmynd_());
+      printf(" in pdspevx pstebz11 me = %d \n", (int)mxmynd_());
       fflush(stdout);
 #endif
       
@@ -913,7 +902,7 @@ for ( iii = 0; iii < msize; iii++)
      
    
 #ifdef DEBUG7
-   printf(" out pdspevx pstebz11 me = %d \n", mxmynd_());
+   printf(" out pdspevx pstebz11 me = %d \n", (int)mxmynd_());
 #endif
    
 #ifdef TIMING
@@ -934,7 +923,7 @@ for ( iii = 0; iii < msize; iii++)
    }
 
    if( *info != 0 ) {
-     fprintf(stderr, " %s me = %d pstebz_ returned info = %d \n", msg, me, *info );
+     fprintf(stderr, " %s me = %d pstebz_ returned info = %d \n", msg, (int)me, (int)(*info) );
      *info = 1;
    }
    
@@ -1026,7 +1015,7 @@ for ( iii = 0; iii < msize; iii++)
     
     
 #ifdef DEBUG7
-      printf(" me = %d just after pstein5 %d \n", me, *info );
+      printf(" me = %d just after pstein5 %d \n", (int)me, (int)(*info) );
       r_ritz_( &msize, dd, &ee[1], eval, mapZ, vecZ, d_scrat);
 #endif
     /*
@@ -1040,7 +1029,7 @@ for ( iii = 0; iii < msize; iii++)
 	 */
       
 #ifdef DEBUG7
-      printf(" me = %d just before pstein4 %d \n", me, *info );
+      printf(" me = %d just before pstein4 %d \n", (int)me, (int)(*info) );
       fflush(stdout);
 #endif
       
@@ -1059,13 +1048,13 @@ for ( iii = 0; iii < msize; iii++)
       
       
 #ifdef DEBUG7
-      printf(" me = %d just after pstein4 %d \n", me, *info );
+      printf(" me = %d just after pstein4 %d \n", (int)me, (int)(*info) );
       fflush(stderr);
 #endif
       
       
       if( *info != 0 ) {
-        fprintf(stderr, " %s me = %d pstein returned info = %d \n", msg, me, *info );
+        fprintf(stderr, " %s me = %d pstein returned info = %d \n", msg, (int)me, (int)(*info) );
         *info = 2;
       }
       
