@@ -11,10 +11,8 @@ void peigs_dlasq1( Integer n, DoublePrecision *dplus, DoublePrecision *lplus, Do
 {   
   Integer i, j, iii, me, nproc;
   DoublePrecision *dptr;
-  extern void ylasq1_();
   FILE *file;
   char filename[40];
-  extern int close();
   
   me    = mxmynd_();
   nproc = mxnprc_();
@@ -27,14 +25,14 @@ void peigs_dlasq1( Integer n, DoublePrecision *dplus, DoublePrecision *lplus, Do
     dptr[i]=lplus[i] * work[i];
   }
   
-  ylasq1_( &n, &work[0], &work[n], &work[n+n], info );
+  dlasq1_( &n, &work[0], &work[n], &work[n+n], info );
   
   if ( *info != 0 ){
-    printf(" error in ylasq1 info = %d \n", *info );
-    sprintf( filename, "pdspevx.%d", me);
+    printf(" error in dlasq1 info = %d \n", (int)(*info) );
+    sprintf( filename, "pdspevx.%d", (int)me);
     file = fopen(filename, "w");
     for ( iii = 0; iii < n; iii++)
-      fprintf(file, " %d %20.16f %20.16f \n", iii, dplus[iii], lplus[iii]);
+      fprintf(file, " %d %20.16f %20.16f \n", (int)iii, dplus[iii], lplus[iii]);
     fclose(file);
     fflush(file);
     fflush(stdout);
@@ -48,7 +46,7 @@ void peigs_dlasq1( Integer n, DoublePrecision *dplus, DoublePrecision *lplus, Do
   return;
   
   /*
-    ylasq1_( n, work, work+ *n, work+2* *n, info );
+    dlasq1_( n, work, work+ *n, work+2* *n, info );
     
     j = *n-1;
     if( fabs(psgn - 1.0) < eps )
