@@ -105,16 +105,6 @@ void pmmLUL(n, mapA, mapvecA, vecA, mapB, mapvecB, vecB,
  * -------------------
  */
 
-   extern void     ycopy_();
-
-   extern Integer      mxmynd_(), mxwrit_(), mxread_();
-   extern Integer count_list();
-   extern Integer reduce_list2();
-   extern void chol_pipe_bcast();
-   extern void     zero_out();
-
-   extern void yaxpy_();
-
 /*
  * Executable code
  * ---------------
@@ -143,7 +133,7 @@ void pmmLUL(n, mapA, mapvecA, vecA, mapB, mapvecB, vecB,
        isize       = *n - mapvecA[i];
        buff_ptr[i] = d_ptr;
        
-       ycopy_(&isize, vecA[i], &ONE, d_ptr, &ONE);
+       dcopy_(&isize, vecA[i], &ONE, d_ptr, &ONE);
        zero_out(isize, vecA[i]);
        
        d_ptr += isize;
@@ -165,8 +155,8 @@ void pmmLUL(n, mapA, mapvecA, vecA, mapB, mapvecB, vecB,
 	      
 	      isize = *n - i - 1;
               if( isize > 0 ) {
-	        ycopy_(&isize, vecB[i_B] + 1,     &ONE, scratch+isize, &MINUSONE);
-	        ycopy_(&isize, buff_ptr[i_A] + 1, &ONE, scratch,         &ONE);
+	        dcopy_(&isize, vecB[i_B] + 1,     &ONE, scratch+isize, &MINUSONE);
+	        dcopy_(&isize, buff_ptr[i_A] + 1, &ONE, scratch,         &ONE);
               }
 	      
 	      isize = 2 * (*n - i - 1) * sizeof(DoublePrecision);
@@ -177,7 +167,7 @@ void pmmLUL(n, mapA, mapvecA, vecA, mapB, mapvecB, vecB,
 	      bbcast00( (char *) scratch, isize, i, mapA[i], num_procs, iscratch );
 	      t     = *vecB[i_B];
 	      isize = *n - i;
-	      yaxpy_(&isize, &t, buff_ptr[i_A], &ONE, vecA[i_A], &ONE);
+	      daxpy_(&isize, &t, buff_ptr[i_A], &ONE, vecA[i_A], &ONE);
 	      
 	      i_B++;
 	      
@@ -192,16 +182,16 @@ void pmmLUL(n, mapA, mapvecA, vecA, mapB, mapvecB, vecB,
 	      
 	      /*
 	       *  B[i][n] is already in the right place in scratch so don't
-	       *  move it.  It wastes time (and would also cause ycopy to
+	       *  move it.  It wastes time (and would also cause dcopy to
 	       *  modified an "aliased" variable (which is illegal in FORTRAN).
 	       */
 	      
 	      isize  = *n - i - 1;
 	      isize0 = isize-1;
               if( isize0 > 0 )
-	         ycopy_(&isize0, scratch + 1,       &ONE, scratch+isize+1, &MINUSONE);
+	         dcopy_(&isize0, scratch + 1,       &ONE, scratch+isize+1, &MINUSONE);
               if( isize > 0 )
-	         ycopy_(&isize,  buff_ptr[i_A] + 1, &ONE, scratch, &ONE);
+	         dcopy_(&isize,  buff_ptr[i_A] + 1, &ONE, scratch, &ONE);
 	      
 	      isize = 2 * (*n - i - 1) * sizeof(DoublePrecision);
 	      /*
@@ -212,7 +202,7 @@ void pmmLUL(n, mapA, mapvecA, vecA, mapB, mapvecB, vecB,
 	      
 
 	      isize = *n - i;
-	      yaxpy_(&isize, &t, buff_ptr[i_A], &ONE, vecA[i_A], &ONE);
+	      daxpy_(&isize, &t, buff_ptr[i_A], &ONE, vecA[i_A], &ONE);
 	      
 	    }
 	  i_A++;
@@ -246,7 +236,7 @@ void pmmLUL(n, mapA, mapvecA, vecA, mapB, mapvecB, vecB,
          {
             t_ptr = d_ptr - (indx - (i + 1));             /* u(i, indx) */
             isize = *n - indx;
-            yaxpy_(&isize, t_ptr, scratch + indx - i - 1, &ONE, vecA[k], &ONE);
+            daxpy_(&isize, t_ptr, scratch + indx - i - 1, &ONE, vecA[k], &ONE);
          }
       }
    }
