@@ -95,9 +95,6 @@ void pmmlsl2(n, mapA, mapvecA, vecA, mapB, mapvecB, vecB,
    * -------------------
    */
 
-  extern void     ycopy_();
-  extern Integer      mxmynd_(), mxwrit_(), mxread_();
-  extern void     zero_out(), de_sym(), mxm_ll();
 
   /*
    * Executable code
@@ -138,7 +135,7 @@ void pmmlsl2(n, mapA, mapvecA, vecA, mapB, mapvecB, vecB,
     zero_out(*n, d_ptr);
     isize  = *n - mapvecA[indx];
     d_ptr += mapvecA[indx];
-    ycopy_(&isize, vecA[indx], &ONE, d_ptr, &ONE);
+    dcopy_(&isize, vecA[indx], &ONE, d_ptr, &ONE);
   }
   buff += nvecsA * *n;
   
@@ -187,7 +184,7 @@ void pmmlsl2(n, mapA, mapvecA, vecA, mapB, mapvecB, vecB,
   
   for ( indx = 0; indx < nvecsA; indx++ ){
     isize = *n - mapvecA[indx];
-    ycopy_(&isize, matrix2[indx] + mapvecA[indx], &ONE, vecA[indx], &ONE);
+    dcopy_(&isize, matrix2[indx] + mapvecA[indx], &ONE, vecA[indx], &ONE);
   }
   
   return;
