@@ -1,6 +1,6 @@
 /*
  $Id$
- *======================================================================ystebz
+ *======================================================================dstebz
  *
  * DISCLAIMER
  *
@@ -151,7 +151,7 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
  *          matrix T is considered to split into a block diagonal
  *          matrix.  On exit, if INFO = 0, IBLOCK(i) specifies to which
  *          block (from 1 to the number of blocks) the eigenvalue EVAL(i)
- *          belongs.  (YSTEBZ may use the remaining N-NEIGVAL elements as
+ *          belongs.  (DSTEBZ may use the remaining N-NEIGVAL elements as
  *          workspace.)
  *
  *  ISPLIT  (output) INTEGER array, dimension (N)
@@ -203,7 +203,7 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
  *               In theory INFO = 2, 3, or 4 should never occur.  If they do occur
  *               then DSTEBZ3 failed to correctly compute the requested eigenvalues.
  *
- *               Note that DSTEBZ3 is a modification of LAPACK's YSTEBZ.  The
+ *               Note that DSTEBZ3 is a modification of LAPACK's DSTEBZ.  The
  *               modifications had to be made to avoid gettings INFOs like 3 and 4.
 
  bug fixed with new lapack code
@@ -232,19 +232,9 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
     *  External Procedures
     */
 
-   extern Integer      mxmynd_(), mxnprc_(), mxwrit_(), mxread_(), mxbrod_();
+   extern Integer      mxmynd_(), mxnprc_();
 
-   extern void     sort_();
-   extern void     dstebz3_();
-
-   extern Integer  menode_();
-   extern Integer  neblw2_();
-   extern Integer  mapchk_();
-   extern void     xstop_(), pdiff(), pgexit();
    DoublePrecision eps, tmp;
-   extern void ysterf_();
-   extern void peigs_tldlfact();
-   extern DoublePrecision dlamch_();
 
    FILE *file;
    char filename[40];
@@ -497,7 +487,7 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
      if ( nn_procs > 1) {
        isize = 2 * sizeof( Integer );
        itype = 15;
-       mxbrod_( i_work, proclist, &isize, &nn_procs, proclist, &itype );
+       mxbrod_( (int *)i_work, proclist, &isize, &nn_procs, proclist, &itype );
        
        nlow  = i_work[ 0 ];
        nhigh = i_work[ 1 ];
@@ -615,7 +605,7 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
    
    if ( *info != 0 ) {
      if ( me == 0 )
-       printf(" PeIGS error from ystebz %d ...trying ysterf \n", (int)*info );
+       printf(" PeIGS error from dstebz %d ...trying dsterf \n", (int)*info );
 
      file = fopen(filename, "a+");
      fprintf(file, "info = %d \n", (int)linfo);
@@ -631,10 +621,10 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
      for (i = 0; i < msize; i++ )
        work[msize + i] = e[i];
      
-     ysterf_( &msize, &work[0], &work[msize+1], info);
+     dsterf_( &msize, &work[0], &work[msize+1], info);
      if ( *info != 0 ){
        if ( me == 0 )
-	 printf(" error from ysterf %d \n", (int)*info );
+	 printf(" error from dsterf %d \n", (int)*info );
      }
      eval[0] = work[0];
    }
@@ -684,11 +674,11 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
      for (i = 0; i < msize; i++ )
        work[msize + i] = e[i];
      
-     ysterf_( &msize, &work[0], &work[msize+1], info);
+     dsterf_( &msize, &work[0], &work[msize+1], info);
 
      if ( *info != 0 ){
        if ( me == 0 )
-	 printf(" error from ysterf %d \n", (int)*info );
+	 printf(" error from dsterf %d \n", (int)*info );
      }
      
      for (i = 0; i < msize; i++ ){
