@@ -43,7 +43,6 @@
 #define max(a,b) ((a) > (b) ? (a) : (b))
 
 #define ZERO  ((DoublePrecision) 0.0e0)
-extern void peigs_tldlfact(), peigs_dlasq1();
 
 
 DoublePrecision psigma, psgn;
@@ -57,7 +56,7 @@ void pstebz11_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
 {
   
   /*
-   *  Parallel version of LAPACK's YSTEBZ.
+   *  Parallel version of LAPACK's DSTEBZ.
    *
    *  This routine is directly callable from both FORTRAN and C.
    *  The documentation below always uses FORTRAN array indexing,
@@ -154,7 +153,7 @@ void pstebz11_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
  *          matrix T is considered to split into a block diagonal
  *          matrix.  On exit, if INFO = 0, IBLOCK(i) specifies to which
  *          block (from 1 to the number of blocks) the eigenvalue EVAL(i)
- *          belongs.  (YSTEBZ may use the remaining N-NEIGVAL elements as
+ *          belongs.  (DSTEBZ may use the remaining N-NEIGVAL elements as
  *          workspace.)
  *
  *  ISPLIT  (output) INTEGER array, dimension (N)
@@ -206,7 +205,7 @@ void pstebz11_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
  *               In theory INFO = 2, 3, or 4 should never occur.  If they do occur
  *               then DSTEBZ3 failed to correctly compute the requested eigenvalues.
  *
- *               Note that DSTEBZ3 is a modification of LAPACK's YSTEBZ.  The
+ *               Note that DSTEBZ3 is a modification of LAPACK's DSTEBZ.  The
  *               modifications had to be made to avoid gettings INFOs like 3 and 4.
 
  bug fixed with new lapack code
@@ -235,14 +234,8 @@ void pstebz11_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
     *  External Procedures
     */
 
-   extern Integer      mxmynd_(), mxnprc_(), mxwrit_(), mxread_(), mxbrod_();
+   extern Integer      mxmynd_(), mxnprc_();
 
-   extern void     dstebz3_(), dstebz31_();
-
-   extern Integer  menode_();
-   extern Integer  neblw2_();
-   extern Integer  mapchk_();
-   extern void     xstop_(), pdiff(), pgexit();
    DoublePrecision leig, reig, eps, shift, tmp1, dummy, tmp; 
    
 
@@ -481,7 +474,7 @@ void pstebz11_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
      if ( nn_procs > 1) {
        isize = 2 * sizeof( Integer );
        itype = 15;
-       mxbrod_( i_work, proclist, &isize, &nn_procs, proclist, &itype );
+       mxbrod_( (int *)i_work, proclist, &isize, &nn_procs, proclist, &itype );
        
        nlow  = i_work[ 0 ];
        nhigh = i_work[ 1 ];
@@ -712,9 +705,9 @@ void pstebz11_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
    
    
    if ( *info != 0 ) {
-     fprintf(stderr, " me = %d ifakeme=%d ylasq1 returned info = %d to pstebz \n",
+     fprintf(stderr, " me = %d ifakeme=%d dlasq1 returned info = %d to pstebz \n",
 	     (int)me, (int)ifakeme, (int)*info );
-     fprintf(stderr, " me = %d ifakeme=%d ylasq1 also returned neig= %d il=%d iu=%d \n",
+     fprintf(stderr, " me = %d ifakeme=%d dlasq1 also returned neig= %d il=%d iu=%d \n",
 	     (int)me, (int)ifakeme, (int)m, (int)il, (int)iu );
      *info = 1;
      exit(-30);
