@@ -54,7 +54,7 @@ void pstebz9_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e,
 {
   
 /*
- *  Parallel version of LAPACK's YSTEBZ.
+ *  Parallel version of LAPACK's DSTEBZ.
  *
  *  This routine is directly callable from both FORTRAN and C.
  *  The documentation below always uses FORTRAN array indexing,
@@ -151,7 +151,7 @@ void pstebz9_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e,
  *          matrix T is considered to split into a block diagonal
  *          matrix.  On exit, if INFO = 0, IBLOCK(i) specifies to which
  *          block (from 1 to the number of blocks) the eigenvalue EVAL(i)
- *          belongs.  (YSTEBZ may use the remaining N-NEIGVAL elements as
+ *          belongs.  (DSTEBZ may use the remaining N-NEIGVAL elements as
  *          workspace.)
  *
  *  ISPLIT  (output) INTEGER array, dimension (N)
@@ -203,7 +203,7 @@ void pstebz9_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e,
  *               In theory INFO = 2, 3, or 4 should never occur.  If they do occur
  *               then DSTEBZ3 failed to correctly compute the requested eigenvalues.
  *
- *               Note that DSTEBZ3 is a modification of LAPACK's YSTEBZ.  The
+ *               Note that DSTEBZ3 is a modification of LAPACK's DSTEBZ.  The
  *               modifications had to be made to avoid gettings INFOs like 3 and 4.
  *
  */
@@ -231,7 +231,7 @@ void pstebz9_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e,
     *  External Procedures
     */
 
-   extern Integer      mxmynd_(), mxnprc_(), mxwrit_(), mxread_(), mxbrod_();
+   extern Integer      mxmynd_(), mxnprc_();
 
    extern void     sort_();
    extern void     dstebz3_();
@@ -469,7 +469,7 @@ void pstebz9_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e,
       if ( nn_procs > 1) {
          isize = 2 * sizeof( Integer );
          itype = 15;
-         mxbrod_( i_work, proclist, &isize, &nn_procs, proclist, &itype );
+         mxbrod_((int *) i_work, proclist, &isize, &nn_procs, proclist, &itype );
 
          nlow  = i_work[ 0 ];
          nhigh = i_work[ 1 ];
@@ -747,7 +747,7 @@ JUNK:
       for ( indx = 0; indx < *n; indx++ )
       work[msize + indx] = e[indx];
       
-      ysterf_(&msize, work, &work[msize], info);
+      dsterf_(&msize, work, &work[msize], info);
       
       for ( indx = 0; indx < *n; indx++ )
       eval[indx] = work[indx];
