@@ -52,7 +52,7 @@ void pstein5 ( n, dd, ee, dplus, lplus, ld, lld, meigval, eval, iblock, nsplit,
   /*
    *
    * Driver to compute eigenvectors of a symmetric tridiagonal matrix.
-   * Basically a parallel version of LAPACK's YSTEIN.
+   * Basically a parallel version of LAPACK's DSTEIN.
    *
    *  n ......... The dimension of the matrix.
    *
@@ -150,16 +150,6 @@ void pstein5 ( n, dd, ee, dplus, lplus, ld, lld, meigval, eval, iblock, nsplit,
 
 
    extern Integer      mxnprc_(), mxmynd_();
-   extern Integer clustrf5_();
-   
-   extern Integer      reduce_list2(), count_list(), clustrinv5_();
-   extern Integer      indxL ();
-   extern void     xstop_();
-   extern void     pgexit();
-   extern void     pdiff();
-   extern void gsum01(), gmax00();
-   extern void bbcast00(), tresid();
-   extern Integer       fil_mapvec_();
    
 
 /*
@@ -178,7 +168,7 @@ void pstein5 ( n, dd, ee, dplus, lplus, ld, lld, meigval, eval, iblock, nsplit,
   
   
 #ifdef DEBUG1
-  fprintf(stderr, "me = %d In pstein \n", me );
+  fprintf(stderr, "me = %d In pstein \n", (int)me );
 #endif
   
   /*
@@ -230,7 +220,7 @@ void pstein5 ( n, dd, ee, dplus, lplus, ld, lld, meigval, eval, iblock, nsplit,
     if ( info != NULL )
         *info = linfo;
     printf( " %s me = %d argument %d is a pointer to NULL. \n",
-	    msg, me, -linfo );
+	    msg, (int)me, (int)(-linfo) );
     fflush(stdout);
     xstop_( &linfo );
     return;
@@ -298,7 +288,7 @@ void pstein5 ( n, dd, ee, dplus, lplus, ld, lld, meigval, eval, iblock, nsplit,
   if( *info != 0 ) {
     linfo = *info;
     printf( " %s me = %d argument %d has an illegal value. \n",
-	    msg, me, -linfo);
+	    msg, (int)me, (int)(-linfo));
     xstop_( info );
     return;
   }
@@ -442,7 +432,7 @@ void pstein5 ( n, dd, ee, dplus, lplus, ld, lld, meigval, eval, iblock, nsplit,
   if ( isize < 0 ){
     *info = -99;
     fprintf(stderr, " Node %d: error in clustrf isize = %d neigval = %d \n", 
-	    me, isize, neigval );
+	    (int)me, (int)isize, (int)neigval );
     xstop_( info );
   }
   
