@@ -173,30 +173,9 @@ void residual2( n, colA, mapA, colB, mapB, m, colZ, mapZ, eval,
   
   DoublePrecision **dbuffptr, **vecZ1, **vecZ2;
   
-  extern void gmax00();
   
+  extern Integer mxmynd_();
   
-  /*
-    blas call
-    */
-  
-  extern DoublePrecision ynrm2_();
-  extern DoublePrecision ydot_();
-  extern void ycopy_();
-  extern void yaxpy_();
-  extern DoublePrecision damax_();
-  
-  extern Integer mxwrit_(), mxread_();
-  extern Integer menode_(), mxmynd_();
-  
-  extern void chol_pipe_bcast();
-  extern Integer fil_mapvec_();
-  extern Integer count_list();
-  extern void mxm88();
-  extern void sonenrm ();
-  extern Integer reduce_list2();
-  extern void    mdiff1_(), mdiff2_(), bbcast00();
-
 
   /*
     usual story about error handling
@@ -255,13 +234,13 @@ void residual2( n, colA, mapA, colB, mapB, m, colZ, mapZ, eval,
   ptr = scrat;
   for ( i = 0; i < nvecsZ; i++ ) {
     vecZ1[i] = ptr;
-    ycopy_( &ll, colZ[i], &IONE, ptr, &IONE );
+    dcopy_( &ll, colZ[i], &IONE, ptr, &IONE );
     ptr += ll;
   }
   
   for ( i = 0; i < nvecsZ; i++ ) {
     vecZ2[i] = ptr;
-    ycopy_( &ll, colZ[i], &IONE, ptr, &IONE );
+    dcopy_( &ll, colZ[i], &IONE, ptr, &IONE );
     ptr += ll;
   }
   
@@ -283,7 +262,7 @@ void residual2( n, colA, mapA, colB, mapB, m, colZ, mapZ, eval,
   for ( i = 0; i < *m; i++ ) {
     if ( mapZ[i] == me ) {
       t = -eval[i];
-      yaxpy_( &ll, &t, vecZ2[k], &IONE, vecZ1[k], &IONE);
+      daxpy_( &ll, &t, vecZ2[k], &IONE, vecZ1[k], &IONE);
       k++;
     }
   }
