@@ -62,8 +62,6 @@ void sorteig( n, neigval, vecZ, mapZ, eval, iwork, work )
                       next, ileft, iright, meval, k;
     Integer           *iorder, *i_work;
 
-    extern void      dshellsort2_(), ycopy_();
-    extern Integer   qqsort();
     extern Integer   mxmynd_(), mxnprc_();
 
 
@@ -204,7 +202,7 @@ void sorteig( n, neigval, vecZ, mapZ, eval, iwork, work )
 
           isaved = indx;
           jlast  = indx;
-          ycopy_( n, vecZ[ indx ], &IONE, work, &IONE );
+          dcopy_( n, vecZ[ indx ], &IONE, work, &IONE );
            
           while ( jj != isaved ) {
 
@@ -213,9 +211,9 @@ void sorteig( n, neigval, vecZ, mapZ, eval, iwork, work )
              iorder[ jlast ] = -1;
 
              if( jj == isaved )
-               ycopy_( n, work, &IONE, vecZ[ jlast ], &IONE );
+               dcopy_( n, work, &IONE, vecZ[ jlast ], &IONE );
              else
-               ycopy_( n, vecZ[ jj ], &IONE, vecZ[ jlast ], &IONE );
+               dcopy_( n, vecZ[ jj ], &IONE, vecZ[ jlast ], &IONE );
   
              jlast = jj;
           }
