@@ -1,10 +1,6 @@
-/*$Id$*/
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if defined(CRAY) && !defined(__crayx1)
-#include <fortran.h>
-#endif
 #if defined(WIN32) &&!defined(__MINGW32__)
 #include "typesf2c.h"
 #endif
@@ -20,6 +16,7 @@ typedef long integer;		/* Equivalent C type to FORTRAN integer */
 #else
 typedef int integer;		/* Equivalent C type to FORTRAN integer */
 #endif
+
 #define FORTRAN_TRUE  ((logical) 1)
 #define FORTRAN_FALSE ((logical) 0)
 
@@ -28,80 +25,28 @@ typedef int integer;		/* Equivalent C type to FORTRAN integer */
 #endif
 
 #define MAX_CLEN 4096
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-static int fortchar_to_string(_fcd f, int flen, char *buf, 
-			      const int buflen)
-#else
+
 static int fortchar_to_string(const char *f, int flen, char *buf, 
 			      const int buflen)
-#endif
 {
-#if (defined(CRAY) || defined(USE_FCD))&& !defined(__crayx1)
-  char *fstring = _fcdtocp(f);
-  flen = _fcdlen(f);
-
-  while (flen-- && fstring[flen] == ' ')
-    ;
-
-  if ((flen+1) >= buflen)
-    return 0;			/* Won't fit */
-
+  while (flen-- && f[flen] == ' ');
+  if ((flen+1) >= buflen) return 0; /* Won't fit */
   flen++;
   buf[flen] = 0;
-  while(flen--)
-    buf[flen] = fstring[flen];
-
-#else
-
-  while (flen-- && f[flen] == ' ')
-    ;
-
-  if ((flen+1) >= buflen)
-    return 0;			/* Won't fit */
-
-  flen++;
-  buf[flen] = 0;
-  while(flen--)
-    buf[flen] = f[flen];
-#endif
+  while(flen--) buf[flen] = f[flen];
   return 1;
 }
-static int string_to_fortchar( f, flen, buf)
-  int flen;
-  char *buf;
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-  _fcd f;
-#else
-  char *f;
-#endif
+static int string_to_fortchar(char *f, int flen, char *buf)
 {
   int len = strlen(buf), i;
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-  flen = _fcdlen(f);
-#endif
 
-  if (len > flen) 
-    return 0;			/* Won't fit */
-
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-  for (i=0; i<len; i++)
-    _fcdtocp(f)[i] = buf[i];
-  for (i=len; i<flen; i++)
-    _fcdtocp(f)[i] = ' ';
-#else
-  for (i=0; i<len; i++)
-    f[i] = buf[i];
-  for (i=len; i<flen; i++)
-    f[i] = ' ';
-#endif
+  if (len > flen) return 0; /* Won't fit */
+  for (i=0; i<len; i++) f[i] = buf[i];
+  for (i=len; i<flen; i++) f[i] = ' ';
   return 1;
 }
 
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-logical context_set_(_fcd  string, int len)
-#else
 logical context_set_(const char *string, int len)
-#endif
 {
   char buf[MAX_CLEN];
 
@@ -110,52 +55,45 @@ logical context_set_(const char *string, int len)
     fflush(stderr);
     return 0;
   }  
-  if (context_set(buf))
+  if (context_set(buf)) {
     return FORTRAN_TRUE;
-  else
+  } else {
     return FORTRAN_FALSE;
+  }
 }
 
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-logical FATR context_get_(_fcd string, int len)
-#else
 logical context_get_(const char *string, int len)
-#endif
 {
   char *tmp = context_get();
   int status = string_to_fortchar(string, len, tmp);
 
   free(tmp);
-  if (status)
+  if (status) {
     return FORTRAN_TRUE;
-  else
+  } else {
     return FORTRAN_FALSE;
+  }
 }
 
 logical context_rtdb_store_(integer *prtdb)
 {
-  if (context_rtdb_store((int) *prtdb))
+  if (context_rtdb_store((int) *prtdb)) {
     return FORTRAN_TRUE;
-  else
+  } else {
     return FORTRAN_FALSE;
+  }
 }
 
 logical context_rtdb_load_(integer *prtdb)
 {
-  if (context_rtdb_load((int) *prtdb))
+  if (context_rtdb_load((int) *prtdb)) {
     return FORTRAN_TRUE;
-  else
+  } else {
     return FORTRAN_FALSE;
+  }
 }
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-logical FATR context_push_(_fcd string)
-#else
 logical context_push_(const char *string, int len)
-#endif
 {
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-  int len = _fcdlen(string);
-#endif
   char buf[MAX_CLEN];
 
   if (!fortchar_to_string(string, len, buf, sizeof buf)) {
@@ -163,20 +101,14 @@ logical context_push_(const char *string, int len)
     fflush(stderr);
     return 0;
   }  
-  if (context_push(buf))
+  if (context_push(buf)) {
     return FORTRAN_TRUE;
-  else
+  } else {
     return FORTRAN_FALSE;
+  }
 }
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-logical FATR context_pop_(_fcd string)
-#else
 logical context_pop_(const char *string, int len)
-#endif
 {
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-  int len = _fcdlen(string);
-#endif
   char buf[MAX_CLEN];
 
   if (!fortchar_to_string(string, len, buf, sizeof buf)) {
@@ -184,47 +116,33 @@ logical context_pop_(const char *string, int len)
     fflush(stderr);
     return 0;
   }  
-  if (context_pop(buf))
+  if (context_pop(buf)) {
     return FORTRAN_TRUE;
-  else
+  } else {
     return FORTRAN_FALSE;
+  }
 }
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-logical FATR context_prefix_(_fcd name, _fcd result)
-#else
 logical context_prefix_(const char *name, char *result, int nlen, int rlen)
-#endif
 {
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-  int nlen = _fcdlen(name);
-  int rlen = _fcdlen(result);
-#endif
   char buf[MAX_CLEN], rbuf[MAX_CLEN];
 
   if (!fortchar_to_string(name, nlen, buf, sizeof(buf))) {
     fprintf(stderr,"context_rtdb_match: buffer too small\n");
     return FORTRAN_FALSE;
   }
-  if (!context_prefix(buf, rbuf, sizeof rbuf))
+  if (!context_prefix(buf, rbuf, sizeof rbuf)) {
     return FORTRAN_FALSE;
+  }
   if (!string_to_fortchar(result, rlen, rbuf)) {
     fprintf(stderr,"context_prefix: result too small\n");
     return FORTRAN_FALSE;
   }
 
-    return FORTRAN_TRUE;
+  return FORTRAN_TRUE;
 }
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-logical FATR context_rtdb_match_(integer *prtdb, _fcd name, _fcd result)
-#else
 logical context_rtdb_match_(integer *prtdb, const char *name, char *result,
 			    int nlen, int rlen)
-#endif
 {
-#if (defined(CRAY) || defined(USE_FCD)) && !defined(__crayx1)
-  int nlen = _fcdlen(name);
-  int rlen = _fcdlen(result);
-#endif
   char buf[MAX_CLEN], rbuf[MAX_CLEN];
 
   if (!fortchar_to_string(name, nlen, buf, sizeof(buf))) {
