@@ -56,6 +56,14 @@ extern int comex_init();
  */
 extern int comex_init_args(int *argc, char ***argv);
 
+/**
+ * Initialize comex with an externally supplied communicator.
+ *
+ * @param[in] comm external communicator.
+ * @return COMEX_SUCCESS on sucess
+ */
+extern int comex_init_comm(MPI_Comm);
+
 /**
  * Test whether comex has been initialized.
  *
@@ -77,7 +85,7 @@ extern int comex_finalize();
  * @param[in] msg the message to print
  * @param[in] code the code to exit with
  */
-extern void comex_error(char *msg, int code);
+extern void comex_error(const char *msg, int code);
 
 /**
  * Create a new group from the given group and process ID list.
