@@ -19,12 +19,7 @@ extern Integer GA_Debug_flag;
 #define FNAM        31              /* length of array names   */
 #define CACHE_SIZE  512             /* size of the cache inside GA DS*/
 
-#ifdef __crayx1
-#define __CRAYX1_PRAGMA _Pragma
-#else
-#define __CRAYX1_PRAGMA(_pragf)
-#endif
-
+/* #define USE_GA_MALLOC */
 enum data_distribution {REGULAR, BLOCK_CYCLIC, SCALAPACK, TILED, TILED_IRREG};
 
 typedef int ARMCI_Datatype;
@@ -160,14 +155,12 @@ extern MPI_Comm GA_MPI_World_comm_dup;
    Integer _loc, _nb, _d, _index, _dim=ndim,_dimstart=0, _dimpos;              \
    for(_nb=1, _d=0; _d<_dim; _d++)_nb *= (Integer)nblock[_d];                  \
    if((Integer)proc > _nb - 1 || proc<0){                                      \
-      __CRAYX1_PRAGMA("_CRI novector");                                        \
-           for(_d=0; _d<_dim; _d++){                                           \
+        for(_d=0; _d<_dim; _d++){                                              \
          lo[_d] = (Integer)0;                                                  \
          hi[_d] = (Integer)-1;}                                                \
    }                                                                           \
    else{                                                                       \
          _index = proc;                                                        \
-      __CRAYX1_PRAGMA("_CRI novector");                                        \
          for(_d=0; _d<_dim; _d++){                                             \
              _loc = _index% (Integer)nblock[_d];                               \
              _index  /= (Integer)nblock[_d];                                   \
@@ -329,7 +322,6 @@ extern MPI_Comm GA_MPI_World_comm_dup;
 #define gam_setstride(ndim, size, ld, ldrem, stride_rem, stride_loc){\
   int _i;                                                            \
   stride_rem[0]= stride_loc[0] = (int)size;                          \
-  __CRAYX1_PRAGMA("_CRI novector");                                  \
   for(_i=0;_i<ndim-1;_i++){                                          \
     stride_rem[_i] *= (int)ldrem[_i];                                \
     stride_loc[_i] *= (int)ld[_i];                                   \
@@ -342,14 +334,12 @@ extern MPI_Comm GA_MPI_World_comm_dup;
       lo, and hi */
 #define gam_CountElems(ndim, lo, hi, pelems){                        \
   int _d;                                                            \
-  __CRAYX1_PRAGMA("_CRI novector");                                         \
   for(_d=0,*pelems=1; _d< ndim;_d++)  *pelems *= hi[_d]-lo[_d]+1;    \
 }
 
 /* NEEDS C_INT64 CONVERSION */
 #define gam_ComputeCount(ndim, lo, hi, count){                       \
   int _d;                                                            \
-  __CRAYX1_PRAGMA("_CRI novector");                                         \
   for(_d=0; _d< ndim;_d++) count[_d] = (int)(hi[_d]-lo[_d])+1;       \
 }
 
@@ -364,7 +354,6 @@ extern MPI_Comm GA_MPI_World_comm_dup;
   _l = strlen(err_string);                                           \
   sprintf(err_string+_l, " [%ld:%ld ",(long)lo[_d],(long)hi[_d]);    \
   _l=strlen(err_string);                                             \
-  __CRAYX1_PRAGMA("_CRI novector");                                  \
   for(_d=1; _d< ndim; _d++){                                         \
     sprintf(err_string+_l, ",%ld:%ld ",(long)lo[_d],(long)hi[_d]);   \
     _l=strlen(err_string);                                           \
@@ -386,7 +375,6 @@ Integer _lo[MAXDIM], _hi[MAXDIM], _p_handle, _iproc;                          \
       _p_handle = GA[g_handle].p_handle;                                      \
       _iproc = proc;                                                          \
       gaCheckSubscriptM(subscript, _lo, _hi, GA[g_handle].ndim);              \
-  __CRAYX1_PRAGMA("_CRI novector");                                           \
       for(_d=0; _d < _last; _d++)            {                                \
           _w = (Integer)GA[g_handle].width[_d];                               \
           _offset += (subscript[_d]-_lo[_d]+_w) * _factor;                    \
@@ -419,7 +407,6 @@ Integer _lo[MAXDIM], _hi[MAXDIM], _p_handle, _iproc;                          \
 #define gaCheckSubscriptM(subscr, lo, hi, ndim)                                \
 {                                                                              \
 Integer _d;                                                                    \
-  __CRAYX1_PRAGMA("_CRI novector");                                            \
    for(_d=0; _d<  ndim; _d++)                                                  \
       if( subscr[_d]<  lo[_d] ||  subscr[_d]>  hi[_d]){                        \
         char err_string[ERR_STR_LEN];                                          \
