@@ -30,8 +30,7 @@ void create_ga(int ndim)
   GA_Destroy(g_A);							
 }
 
-
-main(int argc, char **argv)				
+int main(int argc, char **argv)
 {							
   int rank, nprocs, i;					
 
