@@ -1,4 +1,4 @@
-#if (defined(CRAY) || defined(WIN32) || defined(HITACHI))&&!defined(__crayx1)&&!defined(__MINGW32__)
+#if (defined(CRAY) || defined(WIN32) || defined(HITACHI)) && !defined(__MINGW32__)
 
 #define print_range_  PRINT_RANGE
 #define copy_range_   COPY_RANGE
@@ -37,4 +37,4 @@ extern void print_subscript(char *pre,int ndim, int subscript[], char* post);
 extern void print_distribution(int g_a);
 
 
-/* $Id: testutil.h 26142 2014-09-03 00:26:20Z edo $ */
+/* $Id$ */
