@@ -1,9 +1,5 @@
-/*$Id: util_host.c 26142 2014-09-03 00:26:20Z edo $*/
 #include <stdio.h>
-#if defined(CRAY) && !defined(__crayx1)
-#include <fortran.h>
-#define FATR
-#endif
+
 #if defined(WIN32) && !defined(__MINGW32__)
 #include "typesf2c.h"
 extern int FATR gethostname(char *, int);
@@ -13,17 +9,9 @@ extern int FATR gethostname(char *, int);
 extern int gethostname(char *, int);
 #endif
 
-#if defined(USE_FCD)
-extern int string_to_fortchar(_fcd, int, const char *);
-void FATR UTIL_HOSTNAME(name)
-     _fcd name;
-{
-  int namelen = _fcdlen(name);
-#else
 extern int string_to_fortchar(char *, int, const char *);
 void util_hostname_(char *name, int namelen)
 {
-#endif
 /*
   Utility routine to return hostname to FORTRAN
 
