@@ -1,7 +1,3 @@
-/*
- $Id: util_speak.c 19707 2010-10-29 17:59:36Z d3y133 $
- */
-
 #include <stdio.h>
 #include <string.h>
 #ifdef WIN32
@@ -45,12 +41,7 @@ void util_speak(const char *string)
 #endif
 }
 
-#ifdef CRAY
-#define FATR
-void UTIL_SPEAK(const char *string, int len)
-#else
 void util_speak_(const char *string, int len)
-#endif
 {
 #ifdef SPEECH
     char buf[256];
@@ -62,11 +53,7 @@ void util_speak_(const char *string, int len)
 #endif
 }
 
-#if defined(USE_FCD)
-void FATR UTIL_SPEAK_INIT(const char *host, integer *fp, int len)
-#else
 void util_speak_init_(const char *host, integer *fp, int len)
-#endif
 {
 #ifdef SPEECH
     char buf[256];
