@@ -2,8 +2,7 @@
 UNAME_S=$(uname -s)
 arch=`uname -m`
 if [[ ${UNAME_S} == Linux ]]; then
-    CPU_FLAGS=$(cat /proc/cpuinfo | grep flags |grep -v vmx\ flags |tail -n 1)
-    CPU_FLAGS_2=$(cat /proc/cpuinfo | grep flags |grep -v vmx\ flags |tail -n 1)
+    CPU_FLAGS=$(lscpu | grep -i flags | sort | uniq)
 elif [[ ${UNAME_S} == Darwin ]]; then
     CPU_FLAGS=$(/usr/sbin/sysctl -n machdep.cpu.features)
     if [[ "$arch" == "x86_64" ]]; then
@@ -16,7 +15,7 @@ if [[ $(echo ${CPU_FLAGS}   | tr  'A-Z' 'a-z'| awk ' /clzero/{print "Y"}') == "Y
 elif [[ $(echo ${CPU_FLAGS}   | tr  'A-Z' 'a-z'| awk ' /avx512f/{print "Y"}') == "Y" ]]; then
     echo "avx512"
     exit 0
-elif [[ $(echo ${CPU_FLAGS_2} | tr  'A-Z' 'a-z'| awk ' /avx2/   {print "Y"}') == "Y" ]]; then
+elif [[ $(echo ${CPU_FLAGS} | tr  'A-Z' 'a-z'| awk ' /avx2/   {print "Y"}') == "Y" ]]; then
     echo "avx2"
     exit 0
 elif [[ $(echo ${CPU_FLAGS}   | tr  'A-Z' 'a-z'| awk ' /avx/    {print "Y"}') == "Y" ]]; then
@@ -26,8 +25,19 @@ elif [[ $(echo ${CPU_FLAGS}   | tr  'A-Z' 'a-z'| awk ' /sse2/   {print "Y"}') ==
     echo "sse2"
     exit 0
 elif [[ $arch == "arm64" || $arch == "aarch64" ]]; then
-    echo "arm64"
-    exit 0
+    if [[ $(echo ${CPU_FLAGS}   | tr  'A-Z' 'a-z'| awk ' /sve2/   {print "Y"}') == "Y" ]]; then
+	echo "sve2"
+	exit 0
+    elif [[ $(echo ${CPU_FLAGS}   | tr  'A-Z' 'a-z'| awk ' /sve/   {print "Y"}') == "Y" ]]; then
+	echo "sve"
+	exit 0
+    elif [[ $(echo ${CPU_FLAGS}   | tr  'A-Z' 'a-z'| awk ' /asimddp/   {print "Y"}') == "Y" ]]; then
+	echo "asimddp"
+	exit 0
+    else
+	echo "arm64"
+	exit 0
+    fi
 else
     echo "unknown"
 fi
